@@ -15,7 +15,7 @@ if TYPE_CHECKING:
     from pipen import Pipen, Proc
     from pipen.job import Job
 
-__version__ = "0.3.8"
+__version__ = "0.3.10"
 PATTERN = r"\[PIPEN-POPLOG\]\[(?P<level>\w+?)\] (?P<message>.*)"
 logger = get_logger("poplog")
 levels = {"warn": "warning"}
@@ -185,7 +185,11 @@ class PipenPoplogPlugin(metaclass=Singleton):
 
             # count only when level is larger than poplog_loglevel
             levelno = logging._nameToLevel.get(level.upper(), 0)
-            if not isinstance(levelno, int) or levelno >= logger.getEffectiveLevel():
+            base_logger = getattr(logger, "logger", logger)
+            if (
+                not isinstance(levelno, int)
+                or levelno >= base_logger.getEffectiveLevel()
+            ):
                 populator.increment_counter()
 
     @plugin.impl
@@ -251,6 +255,16 @@ class PipenPoplogPlugin(metaclass=Singleton):
             level = levels.get(level, level)
             msg = match.group("message").rstrip()
             job.log(level, msg, limit_indicator=False, logger=logger)
+            # flush all handlers
+            base_logger = getattr(logger, "logger", logger)
+            for h in getattr(base_logger, "handlers", []):
+                with suppress(Exception):
+                    h.flush()
+
+                stream = getattr(h, "stream", None)
+                if stream:
+                    with suppress(Exception):
+                        stream.flush()
 
             # count only when level is larger than poplog_loglevel
             levelno = logging._nameToLevel.get(level.upper(), 0)
